OpenCV Tutorials {#tutorial_root}
================

The following links describe a set of basic OpenCV tutorials. All the source code mentioned here is
provided as part of the OpenCV regular releases, so check before you start copying & pasting the code.
The list of tutorials below is automatically generated from reST files located in our GIT
repository.

As always, we would be happy to hear your comments and receive your contributions on any tutorial.

-   @subpage tutorial_table_of_content_introduction

    You will learn how to setup OpenCV on your computer

-   @subpage tutorial_table_of_content_core

    Here you will learn
    about the basic building blocks of this library. A must read for understanding how
    to manipulate the images on a pixel level.

-   @subpage tutorial_table_of_content_imgproc

    In this section
    you will learn about the image processing (manipulation) functions inside OpenCV.

-   @subpage tutorial_table_of_content_highgui

    This section contains valuable tutorials on how to use the
    built-in graphical user interface of the library.

-   @subpage tutorial_table_of_content_imgcodecs

    These tutorials show how to read and write images using imgcodecs module.

-   @subpage tutorial_table_of_content_videoio

    These tutorials show how to read and write videos using videio module.

-   @subpage tutorial_table_of_content_calib3d

    Although
    most of our images are in a 2D format they do come from a 3D world. Here you will learn how to find
    out 3D world information from 2D images.

-   @subpage tutorial_table_of_content_features2d

    Learn about how
    to use the feature points detectors, descriptors and matching framework found inside OpenCV.

-   @subpage tutorial_table_of_content_video

    Here you will find
    algorithms usable on your video streams like motion extraction, feature tracking and
    foreground extractions.

-   @subpage tutorial_table_of_content_objdetect

    Ever wondered
    how your digital camera detects people's faces? Look here to find out!

-   @subpage tutorial_table_of_content_dnn

    These tutorials show how to use dnn module effectively.

-   @subpage tutorial_table_of_content_ml

    Use the powerful
    machine learning classes for statistical classification, regression and clustering of data.

-   @subpage tutorial_table_of_content_photo

    Use OpenCV for
    advanced photo processing.

-   @subpage tutorial_table_of_content_stitching

    Learn how to create beautiful photo panoramas and more with OpenCV stitching pipeline.

-   @subpage tutorial_table_of_content_gpu

    Squeeze out every
    little computational power from your system by utilizing the power of your video card to run the
    OpenCV algorithms.

-   @subpage tutorial_table_of_content_ios

    Run OpenCV and your vision apps on an iDevice

-   @subpage tutorial_table_of_content_viz

    These tutorials show how to use Viz module effectively.
